AlignItems enum
Defines how flex items are aligned along the cross axis
- Inheritance
- Available extensions
Values
- start → const AlignItems
-
Items are aligned at the start
- end → const AlignItems
-
Items are aligned at the end
- center → const AlignItems
-
Items are centered
- stretch → const AlignItems
-
Items are stretched to fill the container
- baseline → const AlignItems
-
Items are aligned at their baselines
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCrossAxisAlignment(
) → CrossAxisAlignment -
Available on AlignItems, provided by the AlignItemsExtensions extension
Convert to Flutter's CrossAxisAlignment -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlignItems> - A constant List of the values in this enum, in order of their declaration.