ContainerConverter class
Converts container elements (div, section, article, etc.)
- Inheritance
-
- Object
- ElementConverter<
TagflowElement> - ContainerConverter
Constructors
- ContainerConverter()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedTags
→ Set<
String> -
Supported tags for this converter
Format:
no setteroverride
Methods
-
canHandle(
TagflowNode element) → bool -
Whether this converter can handle the given element
inherited
-
convert(
TagflowElement element, BuildContext context, TagflowConverter converter) → Widget -
Convert the element to a widget
override
-
lookupParent(
TagflowNode element, String tag) → TagflowNode? -
Lookup the first parent of the given tag
inherited
-
matchPositiveSelector(
TagflowNode element, String selector) → bool -
Match positive selectors (without negation)
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveStyle(
TagflowNode element, BuildContext context, {bool inherit = true}) → TagflowStyle -
Get the computed style for an element
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited