FlexWrap enum

Defines how flex items wrap

Inheritance
Available extensions

Values

nowrap → const FlexWrap

Items are laid out in a single line

wrap → const FlexWrap

Items wrap around to additional lines

wrapReverse → const FlexWrap

Items wrap around to additional lines in reverse

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FlexWrap>
A constant List of the values in this enum, in order of their declaration.