JustifyContent enum

Defines how flex items are aligned along the main axis

Inheritance
Available extensions

Values

start → const JustifyContent

Items are packed toward the start

end → const JustifyContent

Items are packed toward the end

center → const JustifyContent

Items are centered along the line

spaceBetween → const JustifyContent

Items are evenly distributed with equal space between each item

spaceAround → const JustifyContent

Items are evenly distributed with equal space around each item

spaceEvenly → const JustifyContent

Items are evenly distributed with equal space between each item

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMainAxisAlignment() MainAxisAlignment

Available on JustifyContent, provided by the JustifyContentExtensions extension

Convert to Flutter's MainAxisAlignment
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<JustifyContent>
A constant List of the values in this enum, in order of their declaration.