SizeValue class

Represents a size value that can be either absolute or relative

Constructors

SizeValue(double _value, [SizeUnit unit = SizeUnit.px])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
unit SizeUnit
final
value double
Get the value in pixels
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context, {double? parentSize}) double
Resolves the size value to pixels based on the context
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited