TagflowConverter class
Main converter that orchestrates the conversion process
Constructors
-
TagflowConverter([List<
ElementConverter< ? customConverters])TagflowNode> > - Create a new converter with optional custom converters
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addAllConverters(
List< ElementConverter< converters) → voidTagflowNode> > - Add multiple custom converters
-
addConverter(
ElementConverter< TagflowNode> converter) → void - Add a custom converter
-
convert(
TagflowNode element, BuildContext context) → Widget - Convert a TagflowElement to a Widget
-
convertChildren(
List< TagflowNode> elements, BuildContext context) → List<Widget> - Convert a list of elements to widgets
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited