TagflowImgElement class

Inheritance
Available extensions

Constructors

TagflowImgElement({String tag = 'img', Map<String, String>? attributes})
const

Properties

alt String?
Returns the alt text for media elements
no setter
attributes LinkedHashMap<String, String>?
Element's attributes
no setteroverride
children List<TagflowNode>
Children nodes
getter/setter pairoverride
classList List<String>
Get the list of classes
getter/setter pairinherited
classList List<String>

Available on TagflowNode, provided by the TagflowNodeStyle extension

Returns class names as a list
getter/setter pair
className String?
Get the class attribute
no setterinherited
className String

Available on TagflowNode, provided by the TagflowNodeStyle extension

Returns the class attribute value
getter/setter pair
fit BoxFit?
Returns the object-fit style as BoxFit
no setter
gap double?

Available on TagflowNode, provided by the TagflowNodeSize extension

Returns the gap between flex items
no setter
hasChildren bool
Whether this node has any children
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
height double?

Available on TagflowNode, provided by the TagflowNodeSize extension

Returns the height as a double
no setter
href String?

Available on TagflowNode, provided by the TagflowNodeLink extension

Returns the href attribute
no setter
isAnchor bool

Available on TagflowNode, provided by the TagflowNodeLink extension

Returns true if this is an anchor element
no setter
isEmpty bool
Whether this node is an empty node
no setterinherited
isFirstChild bool

Available on TagflowNode, provided by the TagflowNodePosition extension

Returns true if this node is the first child of its parent
no setter
isLastChild bool

Available on TagflowNode, provided by the TagflowNodePosition extension

Returns true if this node is the last child of its parent
no setter
isTextNode bool
Whether this node represents a text node
no setterinherited
parent TagflowNode?
Parent node
finalinherited
parentHref String?

Available on TagflowNode, provided by the TagflowNodeLink extension

Returns the parent's href if it exists
no setter
parentTag String
The tag name of the parent element
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String?
Returns the src attribute for media elements
no setter
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
style String?
Get the style attribute
no setterinherited
style String?

Available on TagflowNode, provided by the TagflowNodeStyle extension

Returns the inline style string
no setter
styles Map<String, String>?

Available on TagflowNode, provided by the TagflowNodeStyle extension

Returns parsed inline styles
no setter
tag String
The HTML tag name
finalinherited
target String?

Available on TagflowNode, provided by the TagflowNodeLink extension

Returns the target attribute
no setter
textContent String?
Element's text content
finalinherited
width double?

Available on TagflowNode, provided by the TagflowNodeSize extension

Returns the width as a double
no setter

Methods

hasAttribute(String attribute) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reparent([TagflowNode? newParent]) TagflowNode
Reparent the node
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) String
Get an attribute value
override
operator []=(String key, String value) → void
Set an attribute value
override