TagflowNodePosition extension

Position-related extensions for TagflowNode

on

Properties

isFirstChild bool

Available on TagflowNode, provided by the TagflowNodePosition extension

Returns true if this node is the first child of its parent
no setter
isLastChild bool

Available on TagflowNode, provided by the TagflowNodePosition extension

Returns true if this node is the last child of its parent
no setter