TagflowMetadata class final

Immutable metadata attached to documents, nodes, or source records.

Annotations

Constructors

TagflowMetadata([Map<String, Object?> values = const {}])
Creates a new immutable metadata container.

Properties

hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
Returns true when there are no metadata entries.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, Object?>
Stored metadata values.
final

Methods

merge(TagflowMetadata other) TagflowMetadata
Returns a new container with other overriding matching keys.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override
operator [](String key) Object?
Reads a metadata value by key.

Static Properties

empty TagflowMetadata
An empty metadata container.
final