AlignContent enum
Defines how flex items are aligned along the cross axis
Values
- start → const AlignContent
-
Lines are packed toward the start of the container
- end → const AlignContent
-
Lines are packed toward the end of the container
- center → const AlignContent
-
Lines are packed toward the center of the container
- spaceBetween → const AlignContent
-
Lines are evenly distributed with equal space around each line
- spaceAround → const AlignContent
-
Lines are evenly distributed with equal space before and after each line
- spaceEvenly → const AlignContent
-
Lines are evenly distributed with equal space between each line
- stretch → const AlignContent
-
Lines stretch to take up the remaining space
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlignContent> - A constant List of the values in this enum, in order of their declaration.