ElementConverter<T extends TagflowNode> class
abstract
Base interface for element converters
Constructors
- ElementConverter()
-
Create a new element converter
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedTags
→ Set<
String> -
Supported tags for this converter
Format:
no setter
Methods
-
canHandle(
TagflowNode element) → bool - Whether this converter can handle the given element
-
convert(
T element, BuildContext context, TagflowConverter converter) → Widget - Convert the element to a widget
-
lookupParent(
TagflowNode element, String tag) → TagflowNode? - Lookup the first parent of the given tag
-
matchPositiveSelector(
TagflowNode element, String selector) → bool - Match positive selectors (without negation)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveStyle(
TagflowNode element, BuildContext context, {bool inherit = true}) → TagflowStyle - Get the computed style for an element
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited