resolveStyle method
Get the computed style for an element
If inherit is false, it will not inherit from parent styles
and will return an empty style if no style is found
Implementation
TagflowStyle resolveStyle(
TagflowNode element,
BuildContext context, {
bool inherit = true,
}) {
return TagflowThemeProvider.of(
context,
).resolveStyle(element, inherit: inherit, context: context);
}