FlexDirection enum
Defines the flex direction of a flex container
- Inheritance
- Available extensions
Values
- row → const FlexDirection
-
Items are placed from left to right
- rowReverse → const FlexDirection
-
Items are placed from right to left
- column → const FlexDirection
-
Items are placed from top to bottom
- columnReverse → const FlexDirection
-
Items are placed from bottom to top
Properties
- axis → Axis
-
Convert to Flutter's Axis
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isReversed → bool
-
Whether the direction is reversed
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMainAxisAlignment(
{required bool reverse}) → MainAxisAlignment -
Available on FlexDirection, provided by the FlexTypeExtensions extension
Convert to Flutter's MainAxisAlignment -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FlexDirection> - A constant List of the values in this enum, in order of their declaration.