TagflowImgElement class
- Inheritance
-
- Object
- TagflowNode
- TagflowImgElement
- Available extensions
Constructors
-
TagflowImgElement({String tag = 'img', Map<
String, String> ? attributes}) -
const
Properties
- alt → String?
-
Returns the alt text for media elements
no setter
-
attributes
→ LinkedHashMap<
String, String> ? -
Element's attributes
no setteroverride
-
children
↔ List<
TagflowNode> -
Children nodes
getter/setter pairoverride
-
classList
↔ List<
String> -
Get the list of classes
getter/setter pairinherited
-
classList
↔ List<
String> -
Available on TagflowNode, provided by the TagflowNodeStyle extension
Returns class names as a listgetter/setter pair - className → String?
-
Get the class attribute
no setterinherited
- className ↔ String
-
Available on TagflowNode, provided by the TagflowNodeStyle extension
Returns the class attribute valuegetter/setter pair - fit → BoxFit?
-
Returns the object-fit style as BoxFit
no setter
- gap → double?
-
Available on TagflowNode, provided by the TagflowNodeSize extension
Returns the gap between flex itemsno setter - hasChildren → bool
-
Whether this node has any children
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Available on TagflowNode, provided by the TagflowNodeSize extension
Returns the height as a doubleno setter - href → String?
-
Available on TagflowNode, provided by the TagflowNodeLink extension
Returns the href attributeno setter - isAnchor → bool
-
Available on TagflowNode, provided by the TagflowNodeLink extension
Returns true if this is an anchor elementno setter - isEmpty → bool
-
Whether this node is an empty node
no setterinherited
- isFirstChild → bool
-
Available on TagflowNode, provided by the TagflowNodePosition extension
Returns true if this node is the first child of its parentno setter - isLastChild → bool
-
Available on TagflowNode, provided by the TagflowNodePosition extension
Returns true if this node is the last child of its parentno setter - isTextNode → bool
-
Whether this node represents a text node
no setterinherited
- parent → TagflowNode?
-
Parent node
finalinherited
- parentHref → String?
-
Available on TagflowNode, provided by the TagflowNodeLink extension
Returns the parent's href if it existsno setter - parentTag → String
-
The tag name of the parent element
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- src → String?
-
Returns the src attribute for media elements
no setter
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - style → String?
-
Get the style attribute
no setterinherited
- style → String?
-
Available on TagflowNode, provided by the TagflowNodeStyle extension
Returns the inline style stringno setter -
styles
→ Map<
String, String> ? -
Available on TagflowNode, provided by the TagflowNodeStyle extension
Returns parsed inline stylesno setter - tag → String
-
The HTML tag name
finalinherited
- target → String?
-
Available on TagflowNode, provided by the TagflowNodeLink extension
Returns the target attributeno setter - textContent → String?
-
Element's text content
finalinherited
- width → double?
-
Available on TagflowNode, provided by the TagflowNodeSize extension
Returns the width as a doubleno setter
Methods
-
hasAttribute(
String attribute) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reparent(
[TagflowNode? newParent]) → TagflowNode -
Reparent the node
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → String -
Get an attribute value
override
-
operator []=(
String key, String value) → void -
Set an attribute value
override