TagflowParser class
Parses HTML string into TagflowElement
Constructors
-
TagflowParser({List<
NodeParser< ? parsers, bool debug = false, TagflowRenderBoundary? renderBoundary})TagflowNode> > -
const
Properties
- debug → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- renderBoundary → TagflowRenderBoundary?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isValidNode(
TagflowNode node) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String input) → TagflowNode -
parseNode(
Node node) → TagflowNode? -
parseNodes(
NodeList nodes) → List< TagflowNode> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited