TagflowOptions class final
Legacy alpha compatibility wrapper for runtime view options.
Prefer TagflowViewOptions for new code. TagflowRenderBoundary remains on
this compatibility type so existing HTML-first usage continues to work while
the alpha API moves HTML-only parsing behavior onto Tagflow.html(...) and
the HTML adapter.
Constructors
- TagflowOptions({bool debug = false, TagflowLinkTapCallback? linkTapCallback, TagflowSelectableOptions selectable = const TagflowSelectableOptions(), ImageLoadingBuilder? imageLoadingBuilder, ImageErrorWidgetBuilder? imageErrorBuilder, double? maxImageWidth, double? maxImageHeight, bool enableImageCache = true, TagflowErrorWidgetBuilder? errorBuilder, TagflowRenderBoundary? renderBoundary})
-
Creates a new TagflowOptions instance.
const
- TagflowOptions.fromViewOptions(TagflowViewOptions options, {TagflowRenderBoundary? renderBoundary})
-
Creates legacy options from the new runtime view options.
factory
Properties
- debug → bool
-
Enable debug mode
final
- enableImageCache → bool
-
Whether to cache images
final
- errorBuilder → TagflowErrorWidgetBuilder?
-
Custom widget builder for unrecoverable parsing or rendering errors.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageErrorBuilder → ImageErrorWidgetBuilder?
-
Custom image error widget builder
final
- imageLoadingBuilder → ImageLoadingBuilder?
-
Custom image loading widget builder
final
- linkTapCallback → TagflowLinkTapCallback?
-
Callback for handling link taps
final
- maxImageHeight → double?
-
Maximum height for images
final
- maxImageWidth → double?
-
Maximum width for images
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- renderBoundary → TagflowRenderBoundary?
-
Optional boundary that stops rendering part-way through the HTML tree.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectable → TagflowSelectableOptions
-
Options for configuring the selectable behavior
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{bool? debug, TagflowLinkTapCallback? linkTapCallback, TagflowSelectableOptions? selectable, ImageLoadingBuilder? imageLoadingBuilder, ImageErrorWidgetBuilder? imageErrorBuilder, double? maxImageWidth, double? maxImageHeight, bool? enableImageCache, TagflowErrorWidgetBuilder? errorBuilder, TagflowRenderBoundary? renderBoundary}) → TagflowOptions - Create a copy with some properties replaced
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toViewOptions(
) → TagflowViewOptions - Converts these compatibility options into the runtime view options.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
maybeOf(
BuildContext context) → TagflowOptions? - Get options from context if available
-
of(
BuildContext context) → TagflowOptions - Get options from context
Constants
- defaults → const TagflowOptions
- Default options