TagflowRenderBoundary class final
Boundary that limits rendering when matched while parsing the HTML tree.
Constructors
- TagflowRenderBoundary.comment({String? start, String? end, bool caseSensitive = false})
-
Renders content between optional HTML comment markers.
const
Properties
- caseSensitive → bool
-
Whether comment matching should be case-sensitive.
final
- end → String?
-
Optional comment marker that stops rendering before it is encountered.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → String?
-
Optional comment marker that starts rendering after it is encountered.
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
matchesEndComment(
String comment) → bool -
Returns true when
commentmatches end. -
matchesStartComment(
String comment) → bool -
Returns true when
commentmatches start. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited